@@ -73,6 +73,12 @@ class OptionUnavailable(Exception):
         self.message = message
         super().__init__(self.message)
 
+class ConfigNotFound(Exception):
+    def __init__(self, config, message="Supplied config cannot be found, probably cause it does not exist"):
+        self.config = config
+        self.message = message
+        super().__init__(self.message)
+
 class account:
     def login(email:str=None, password:str=None):
         if (email == None or password == None) or (email == None and password == None):
@@ -100,7 +106,7 @@ class settings:
     def listsettings(config,header):
         list = requests.get(f"https://api.nextdns.io/configurations/{config}/settings", headers=header)
         if list.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             list = list.json()
             return list
@@ -111,16 +117,16 @@ class settings:
     def clearlogs(config,header):
         logs = requests.delete(f"https://api.nextdns.io/configurations/{config}/logs", headers = header)
         if logs.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
     def rename(name, config, header):
         name = {"name":name}
         rename = requests.patch(f"https://api.nextdns.io/configurations/{config}/settings", headers = header, json=name)
         if rename.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
     def delete(config,header):
         dconfig = requests.delete(f"https://api.nextdns.io/configurations/{config}", headers = header)
         if dconfig.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
     def logclientips(bool, config, header):
         if bool == True:
             bool = "true"
@@ -128,9 +134,8 @@ class settings:
             bool = "false"
         logcips = {"logging_disable_client":bool}
         logcips = requests.patch(f"https://api.nextdns.io/configurations/{config}/settings", headers = header, json=logcips)
-        print(logcips.text)
         if logcips.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
     def logdomains(bool, config, header):
         if bool == True:
             bool = "true"
@@ -138,9 +143,8 @@ class settings:
             bool = "false"
         logdom = {"logging_disable_query":bool}
         logdom = requests.patch(f"https://api.nextdns.io/configurations/{config}/settings", headers = header, json=logdom)
-        print(logdom.text)
         if logdom.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
     def blockpage(bool,config, header):
         if bool == True:
             bool = "true"
@@ -148,9 +152,8 @@ class settings:
             bool = "false"
         bp = {"blockPage":bool}
         bp = requests.patch(f"https://api.nextdns.io/configurations/{config}/settings", headers = header, json=bp)
-        print(bp.text)
         if bp.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
     def updatelinkedip(config,header):
         r = settings.setup(config, header)
         updatetoken = r["linkedIpUpdateToken"]
@@ -161,7 +164,7 @@ class security:
     def list(config, header):
         settings = requests.get(f"https://api.nextdns.io/configurations/{config}/security", headers = header)
         if settings.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             settings = settings.json()
             return settings
@@ -173,7 +176,7 @@ class security:
         setting = {"threatIntelligenceFeeds":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def aidetection(bool, config, header):
@@ -183,9 +186,8 @@ class security:
             bool = "false"
         setting = {"aiThreatDetection":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
-        print(setting.text)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def safebrowsing(bool, config, header):
@@ -196,7 +198,7 @@ class security:
         setting = {"googleSafeBrowsing":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def cryptojacking(bool, config, header):
@@ -207,7 +209,7 @@ class security:
         setting = {"cryptojacking":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def dnsrebinding(bool, config, header):
@@ -218,7 +220,7 @@ class security:
         setting = {"dnsRebinding":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def homograph(bool, config, header):
@@ -229,7 +231,7 @@ class security:
         setting = {"homograph":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def typosquatting(bool, config, header):
@@ -240,7 +242,7 @@ class security:
         setting = {"typosquatting":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def dga(bool, config, header):
@@ -251,7 +253,7 @@ class security:
         setting = {"dga":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def newdomains(bool, config, header):
@@ -262,7 +264,7 @@ class security:
         setting = {"nrd":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def parked(bool, config, header):
@@ -273,7 +275,7 @@ class security:
         setting = {"parked":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def csam(bool, config, header): 
@@ -284,25 +286,23 @@ class security:
         setting = {"csam":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/security", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def addtld(tld, config, header):
         hex = tld.encode('utf-8').hex()
         hex = f"hex:{hex}"
         put = requests.put(f"https://api.nextdns.io/configurations/{config}/security/blocked_tlds/{tld}", headers = header)
-        print(put.text)
     def removetld(tld, config, header):
         hex = tld.encode('utf-8').hex()
         hex = f"hex:{hex}"
         remove = requests.delete(f"https://api.nextdns.io/configurations/{config}/security/blocked_tlds/{tld}", headers = header)
-        print(remove.text)
 
 class privacy:
     def list(config, header):
         settings = requests.get(f"https://api.nextdns.io/configurations/{config}/privacy", headers = header)
         if settings.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             settings = settings.json()
             return settings
@@ -313,9 +313,8 @@ class privacy:
             bool = "false"
         setting = {"blockDisguised":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/privacy", headers = header, json=setting)
-        print(setting.text)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return "OK"
     def blockaffiliate(bool, config, header):
@@ -325,29 +324,28 @@ class privacy:
             bool = "true"
         setting = {"allowAffiliate":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/privacy", headers = header, json=setting)
-        print(setting.text)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return "OK"
     def blocknative(native, config, header):
         hex = native.encode('utf-8').lower().hex()
-        print(hex)
+        
         if hex in nativetrackinghex:
             hex = f"hex:{hex}"
             put = requests.put(f"https://api.nextdns.io/configurations/{config}/privacy/natives/{hex}", headers = header)
             if put.text == "Not Found":
-                print(f'Config {config} not found.')
+                raise ConfigNotFound(config)
             else:
                 return "OK"
     def unblocknative(native, config, header):
         hex = native.encode('utf-8').lower().hex()
-        print(hex)
+        
         if hex in nativetrackinghex:
             hex = f"hex:{hex}"
             delete = requests.delete(f"https://api.nextdns.io/configurations/{config}/privacy/natives/{hex}", headers = header)
             if delete.text == "Not Found":
-                print(f'Config {config} not found.')
+                raise ConfigNotFound(config)
             else:
                 return "OK"
 
@@ -356,7 +354,7 @@ class parental:
         settings = requests.get(f"https://api.nextdns.io/configurations/{config}/parentalcontrol", headers = header)
         sites = requests.get(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/services/@all")
         if settings.text == "Not Found" or sites.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             settings = settings.json()
             sites = sites.json()
@@ -367,7 +365,7 @@ class parental:
         else:
             setting = requests.delete(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/categories/hex:706f726e", headers = header)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return setting.text
     def gambling(bool, config, header):
@@ -376,7 +374,7 @@ class parental:
         else:
             setting = requests.delete(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/categories/hex:67616d626c696e67", headers = header)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return setting.text
     def dating(bool, config, header):
@@ -385,7 +383,7 @@ class parental:
         else:
             setting = requests.delete(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/categories/hex:646174696e67", headers = header)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return setting.text
     def piracy(bool, config, header):
@@ -394,7 +392,7 @@ class parental:
         else:
             setting = requests.delete(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/categories/hex:706972616379", headers = header)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return setting.text
     def socialnetworks(bool, config, header):
@@ -403,7 +401,7 @@ class parental:
         else:
             setting = requests.delete(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/categories/hex:736f6369616c2d6e6574776f726b73", headers = header)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return setting.text
     def safesearch(bool, config, header):
@@ -414,7 +412,7 @@ class parental:
         setting = {"safeSearch":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/parentalcontrol", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def blockbypass(bool, config, header):
@@ -425,26 +423,25 @@ class parental:
         setting = {"blockBypass":bool}
         setting = requests.patch(f"https://api.nextdns.io/configurations/{config}/parentalcontrol", headers = header, json=setting)
         if setting.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return settings
     def blocksite(site, config, header):
         try:
             sitehex = siteshex[f"{site.lower()}"]
         except:
-            raise OptionUnavailable(allowed=sites)
+            raise OptionUnavailable(allowed=siteshex)
         
         hex = f"hex:{sitehex}"
-        print(hex)
+        
         put = requests.put(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/services/{hex}", headers = header)
-        print(put.text)
         return "OK"
     def unblocksite(site, config, header):
         sitehex = siteshex[f"{site.lower()}"]
         hex = f"hex:{sitehex}"
         delete = requests.delete(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/services/{hex}", headers = header)
         if delete.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             return "OK"
 
@@ -452,7 +449,7 @@ class denylist:
     def list(config, header):
         list = requests.get(f"https://api.nextdns.io/configurations/{config}/denylist", headers=header)
         if list.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             list = list.json()
             return list
@@ -471,23 +468,19 @@ class allowlist:
     def list(config, header):
         settings = requests.get(f"https://api.nextdns.io/configurations/{config}/allowlist", headers = header)
         if settings.text == "Not Found":
-            print(f'Config {config} not found.')
+            raise ConfigNotFound(config)
         else:
             settings = settings.json()
             return settings
     def add(domain, config, header):
         hex = domain.encode('utf-8').hex()
         hex = f"hex:{hex}"
-        print(hex)
         put = requests.put(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/allowlist/{hex}", headers = header)
-        print(put.text)
         return "OK"
     def remove(domain, config, header):
         hex = domain.encode('utf-8').hex()
         hex = f"hex:{hex}"
-        print(hex)
         put = requests.delete(f"https://api.nextdns.io/configurations/{config}/parentalcontrol/allowlist/{hex}", headers = header)
-        print(put.text)
         return "OK"
 
 class analytics:
